/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 1996, California Institute of Technology.  
// ALL RIGHTS RESERVED.   U.S. Government Sponsorship acknowledged. 
//
// Please read the full copyright notice in the file COPYRIGH 
// in this directory.
//
// Author: Todd Karakashian, NASA/Jet Propulsion Laboratory
//         Todd.K.Karakashian@jpl.nasa.gov
//
// $RCSfile: dodsutil.cc,v $ - Miscellaneous routines for DODS HDF server
//
// $Log: dodsutil.cc,v $
// Revision 1.4.8.2  2000/03/20 22:25:24  jimg
// Removed duplicates of the functions in the dap file escaping.cc. These
// were old and not getting fixed up; I'd rather just work on one copy of the
// escaping functions!
//
// Revision 1.4.8.1  2000/03/09 00:24:59  jimg
// Replaced int and uint32 with string::size_type
//
// Revision 1.4  1999/05/06 03:23:35  jimg
// Merged changes from no-gnu branch
//
// Revision 1.3.6.1  1999/05/06 00:27:23  jimg
// Jakes String --> string changes
//
// Revision 1.2  1998/02/05 20:14:30  jimg
// DODS now compiles with gcc 2.8.x
//
// Revision 1.1  1997/03/10 22:55:01  jimg
// New files for the 2.12 compatible HDF server
//
// Revision 1.3  1996/11/20  22:28:43  todd
// Modified to support UInt32 type.
//
// Revision 1.2  1996/10/07 21:15:17  todd
// Changes escape character to % from _.
//
// Revision 1.1  1996/09/24 22:38:16  todd
// Initial revision
//
//
/////////////////////////////////////////////////////////////////////////////

#include <strstream.h>
#include <iomanip>
#include <string>
#include <Regex.h>
#include "HDFStructure.h"
#include "HDFArray.h"
#include "dodsutil.h"
#include "dhdferr.h"
#include "hdf-dods.h"

int regindex(const string &s, const Regex &r, int index = 0) {
  int matchlen;
  return r.search(s.c_str(), s.size(), matchlen, index);
}

HDFStructure *CastBaseTypeToStructure(BaseType *p) {
    if (p->type_name() != "Structure")
	THROW(dhdferr_consist);
    return (HDFStructure *)p;
}

HDFArray *CastBaseTypeToArray(BaseType *p) {
    if (p->type_name() != "Array")
	THROW(dhdferr_consist);
    return (HDFArray *)p;
}

int *CastBaseTypeToInt(BaseType *p) {
    if (p->type_name() != "Int32")
	THROW(dhdferr_consist);
    return (int *)p;
}

double *CastBaseTypeToDouble(BaseType *p) {
    if (p->type_name() != "Float64")
	THROW(dhdferr_consist);
    return (double *)p;
}

